@@ -18,12 +18,66 @@ try:
 except ImportError:
    print('Error, yaml is required, please run pip install pyyaml')
 
+
+maxtests=1000000 #default 10000000
+fail="newdefects, reopeneddefects" #default new defects and reopened defects  #options newdefects, reopeneddefects, flakybrokentests, newflaky, reopenedflaky, failedtests, brokentests
+additionalargs="" #default ''
+testseparator="" #default ' '
+postfixtest="" #default ''
+prefixtest="" #default ''
+fullnameseparator="" #default ''
+fullname="false" #default false
+failfast="false" #defult false
+maxrerun=3 #default 3
+rerun="true" #default false
+importtype="junit" #default junit
+reporttype="directory" #default directory other option file, when directory needs to end with /
+teststorun="all" #options include - high, medium, low, unassigned, ready, open, none
+deletereports="false" #options true or false, BE CAREFUL THIS WILL DELETE THE SPECIFIC FILE OR ALL XML FILES IN THE DIRECTORY
+startrunall = "" #startrun needs to end with a space sometimes
+endrunall = ""#endrun needs to start with a space sometimes
+startrunspecific = "" #startrun needs to end with a space sometimes
+endrunspecific = ""#endrun needs to start with a space sometimes
+commit=""
+scriptlocation="./"
+branch=""
+#runfrequency="single" #options single for single commits, lastrun for all commits since the last run, betweeninclusive or betweenexclusive for all commits between two commits either inclusive or exclusive
+runfrequency="multiple" #options single for ['Single', 'LastRun', 'BetweenInclusive', 'BetweenExclusive']
+fromcommit=""
+repository="git"
+scriptlocation="./"
+generatefile="false"
+template="none"
+addtestsuitename="false"
+addclassname="false"
+runtemplate=""
+testsuitesnameseparator=""
+testtemplate=""
+classnameseparator=""
+testseparatorend=""
+testtemplatearg1=""
+testtemplatearg2=""
+testtemplatearg3=""
+testtemplatearg4=""
+startrunpostfix=""
+endrunprefix=""
+endrunpostfix=""
+executetests = "true"
+encodetests = "false"
+testsuiteencoded=""
+projectencoded=""
+
 tests=""
 testsrun=""
 run_id=""
 proxy=""
 username=""
 password=""
+url = ""
+apikey =""
+project =""
+testsuite =""
+report = ""
 
 
 def find(name):
@@ -454,7 +508,7 @@ def get_and_run_tests(type):
     #        execute_tests("", 0)
 
 #def failfast_tests(tests):
-def failfast_tests(tests):
+def failfast_tests():
     if failfast == "true":
         rerun_tests()
         getresults()
@@ -595,7 +649,13 @@ def call_import(filepath):
         print(('[?] Unexpected Error: [HTTP {0}]: Content: {1}'.format(response.status_code, response.content)))
 
 
-def runtestswithappsurify(*argv):
+def runtestswithappsurify(*args):
+    global tests, teststorun, run_id, proxy, username, password, url, apikey, project, testsuite, report, maxtests, fail, additionalargs, testseparator, postfixtest, prefixtest
+    global fullnameseparator, fullname, failfast, maxrerun, rerun, importtype, reporttype, teststorun, deletereports, startrunall, endrunall, startrunspecifi, endrunspecific
+    global commit, scriptlocation, branch, runfrequency, fromcommit, repository, scriptlocation, generatefile, template, addtestsuitename, addclassname, runtemplate, testsuitesnameseparator
+    global testtemplate, classnameseparator, testseparatorend, testtemplatearg1, testtemplatearg2, testtemplatearg3, testtemplatearg4, startrunpostfix, endrunprefix
+    global endrunpostfix, executetests, encodetests, testsuiteencoded, projectencoded, testsrun
+
     tests=""
     testsrun=""
     run_id=""
@@ -656,9 +716,11 @@ def runtestswithappsurify(*argv):
 
 
     #Templates
-
+    argv = args[0]
+    if type(argv) == tuple:
+        argv = argv[0]
     c=0
-
+    print("===================================")
     if len(argv) > 1 :
         c=len(argv)
         for k in range(1,c):
@@ -1253,8 +1315,12 @@ def runtestswithappsurify(*argv):
         print(("testsrun1 = " + testsrun))
         testsrun = get_and_run_tests(i) + testsrun
 
+    print(testsrun)
+
     os.environ["TESTSTORUN"] = testsrun
 
+    
+
     if testsrun == "":
             print("executing all tests")
             execute_tests("", 0)
@@ -1267,4 +1333,10 @@ def runtestswithappsurify(*argv):
     if failfast == "false" and rerun == "true" and teststorun != "none":
         rerun_tests()
 
-    getresults()
\ No newline at end of file
+    getresults()
+
+def main(*argv):
+    print(argv)
+    runtestswithappsurify(argv)
+  
+main(sys.argv)
\ No newline at end of file
